@@ -1,4 +1,4 @@
-require 'gen/ConstGenerator'
+require_relative '../../gen/ConstGenerator'
 def gen_rlimit_java(options)
   ConstGenerator.new 'platform.rlimit', options do |cg|
     cg.include "stdint.h"
@@ -25,4 +25,4 @@ def gen_rlimit_java(options)
       RLIMIT_STACK
     ].each {|c| cg.const c }
   end
-end
\ No newline at end of file
+end
