@@ -1,7 +1,7 @@
 require_relative '../../gen/ConstGenerator'
 def gen_sock_java(options)
   ConstGenerator.new 'platform.sock', options do |cg|
-    cg.include "sys/socket.h"
+    cg.include IS_WINDOWS ? "Winsock2.h" : "sys/socket.h"
     %w[
       SOCK_STREAM
       SOCK_DGRAM
