@@ -1,7 +1,7 @@
 require_relative '../../gen/ConstGenerator'
 def gen_socketoption_java(options)
   ConstGenerator.new 'platform.socket_option', options do |cg|
-    cg.include "sys/socket.h"
+    cg.include IS_WINDOWS ? "Ws2spi.h" : "sys/socket.h"
     %w[
       SO_DEBUG
       SO_ACCEPTCONN
